@@ -52,164 +52,32 @@
 
 (in-package :user)
 
-#+excl
-(eval-when (compile load eval)
-  (when (eq (find-package :lisp) (find-package :common-lisp))
-    (let ((excl::*enable-package-locked-errors* nil))
-      (rename-package :common-lisp :common-lisp '(:cl)))
-    (make-package :lisp :use nil)
-    ((lambda (symbols)
-       (import symbols :lisp)
-       (export symbols :lisp))
-     '(&allow-other-keys &aux &body &environment &key &optional &rest &whole
-       * ** *** *applyhook* *break-on-warnings* *debug-io*
-       *default-pathname-defaults* *error-output* *evalhook* *features*
-       *load-verbose* *macroexpand-hook* *modules* *package* *print-array*
-       *print-base* *print-case* *print-circle* *print-escape*
-       *print-gensym* *print-length* *print-level* *print-pretty*
-       *print-radix* *query-io* *random-state* *read-base*
-       *read-default-float-format* *read-suppress* *readtable*
-       *standard-input* *standard-output* *terminal-io* *trace-output* +
-       ++ +++ - / // /// /= 1+ 1- < <= = > >= abs acons acos acosh adjoin
-       adjust-array adjustable-array-p akcl alpha-char-p alphanumericp and
-       append apply applyhook apropos apropos-list aref array
-       array-dimension array-dimension-limit array-dimensions
-       array-element-type array-has-fill-pointer-p array-in-bounds-p
-       array-rank array-rank-limit array-row-major-index array-total-size
-       array-total-size-limit arrayp ash asin asinh assert assoc assoc-if
-       assoc-if-not atan atanh atom bignum bit bit-and bit-andc1 bit-andc2
-       bit-eqv bit-ior bit-nand bit-nor bit-not bit-orc1 bit-orc2
-       bit-vector bit-vector-p bit-xor block boole boole-1 boole-2
-       boole-and boole-andc1 boole-andc2 boole-c1 boole-c2 boole-clr
-       boole-eqv boole-ior boole-nand boole-nor boole-orc1 boole-orc2
-       boole-set boole-xor both-case-p boundp break butlast byte
-       byte-position byte-size caaaar caaadr caaar caadar caaddr caadr
-       caar cadaar cadadr cadar caddar cadddr caddr cadr
-       call-arguments-limit car case catch ccase cdaaar cdaadr cdaar
-       cdadar cdaddr cdadr cdar cddaar cddadr cddar cdddar cddddr cdddr
-       cddr cdr ceiling cerror char char-bit char-bits char-bits-limit
-       char-code char-code-limit char-control-bit char-downcase char-equal
-       char-font char-font-limit char-greaterp char-hyper-bit char-int
-       char-lessp char-meta-bit char-name char-not-equal char-not-greaterp
-       char-not-lessp char-super-bit char-upcase char/= char< char<= char=
-       char> char>= character characterp check-type cis clear-input
-       clear-output close clrhash code-char coerce common commonp
-       compilation-speed compile compile-file compiled-function
-       compiled-function-p compiler-let complex complexp concatenate cond
-       conjugate cons consp constantp copy-alist copy-list copy-readtable
-       copy-seq copy-symbol copy-tree cos cosh count count-if count-if-not
-       ctypecase decf declaration declare decode-float
-       decode-universal-time defconstant define-modify-macro
-       define-setf-method defmacro defparameter defsetf defstruct deftype
-       defun defvar delete delete-duplicates delete-file delete-if
-       delete-if-not denominator deposit-field describe digit-char
-       digit-char-p directory directory-namestring disassemble do do*
-       do-all-symbols do-external-symbols do-symbols documentation dolist
-       dotimes double-float double-float-epsilon
-       double-float-negative-epsilon dpb dribble ecase ed eighth elt
-       encode-universal-time endp enough-namestring eq eql equal equalp
-       error etypecase eval eval-when evalhook evenp every exp export expt
-       fboundp fceiling ffloor fifth file-author file-length
-       file-namestring file-position file-write-date fill fill-pointer
-       find find-all-symbols find-if find-if-not find-package find-symbol
-       finish-output first fixnum flet float float-digits float-precision
-       float-radix float-sign floatp floor fmakunbound force-output format
-       fourth fresh-line fround ftruncate ftype funcall function functionp
-       gcd gensym gentemp get get-decoded-time
-       get-dispatch-macro-character get-internal-real-time
-       get-internal-run-time get-macro-character get-output-stream-string
-       get-properties get-setf-method get-setf-method-multiple-value
-       get-universal-time getf gethash gfun go graphic-char-p hash-table
-       hash-table-count hash-table-p host-namestring identity if ignore
-       imagpart import in-package incf inline input-stream-p inspect
-       int-char integer integer-decode-float integer-length integerp
-       intern internal-time-units-per-second intersection isqrt keyword
-       keywordp labels lambda lambda-list-keywords lambda-parameters-limit
-       last lcm ldb ldb-test ldiff least-negative-double-float
-       least-negative-long-float least-negative-short-float
-       least-negative-single-float least-positive-double-float
-       least-positive-long-float least-positive-short-float
-       least-positive-single-float length let let*
-       lisp-implementation-type lisp-implementation-version list list*
-       list-all-packages list-length listen listp load locally log logand
-       logandc1 logandc2 logbitp logcount logeqv logior lognand lognor
-       lognot logorc1 logorc2 logtest logxor long-float long-float-epsilon
-       long-float-negative-epsilon long-site-name loop lower-case-p
-       machine-instance machine-type machine-version macro-function
-       macroexpand macroexpand-1 macrolet make-array make-broadcast-stream
-       make-char make-concatenated-stream make-dispatch-macro-character
-       make-echo-stream make-hash-table make-list make-package
-       make-pathname make-random-state make-sequence make-string
-       make-string-input-stream make-string-output-stream make-symbol
-       make-synonym-stream make-two-way-stream makunbound map mapc mapcan
-       mapcar mapcon maphash mapl maplist mask-field max member member-if
-       member-if-not merge merge-pathnames min minusp mips mismatch mod
-       most-negative-double-float most-negative-fixnum
-       most-negative-long-float most-negative-short-float
-       most-negative-single-float most-positive-double-float
-       most-positive-fixnum most-positive-long-float
-       most-positive-short-float most-positive-single-float
-       multiple-value-bind multiple-value-call multiple-value-list
-       multiple-value-prog1 multiple-value-setq multiple-values-limit
-       name-char namestring nbutlast nconc nil nintersection ninth not
-       notany notevery notinline nreconc nreverse nset-difference
-       nset-exclusive-or nstring-capitalize nstring-downcase
-       nstring-upcase nsublis nsubst nsubst-if nsubst-if-not nsubstitute
-       nsubstitute-if nsubstitute-if-not nth nthcdr null number numberp
-       numerator nunion oddp open optimize or otherwise output-stream-p
-       package package-name package-nicknames package-shadowing-symbols
-       package-use-list package-used-by-list packagep pairlis
-       parse-integer parse-namestring pathname pathname-device
-       pathname-directory pathname-host pathname-name pathname-type
-       pathname-version pathnamep peek-char phase pi plusp pop position
-       position-if position-if-not pprint prin1 prin1-to-string princ
-       princ-to-string print probe-file proclaim prog prog* prog1 prog2
-       progn progv provide psetf psetq push pushnew quote random
-       random-state random-state-p rassoc rassoc-if rassoc-if-not ratio
-       rational rationalize rationalp read read-byte read-char
-       read-char-no-hang read-delimited-list read-from-string read-line
-       read-preserving-whitespace readtable readtablep realpart reduce rem
-       remf remhash remove remove-duplicates remove-if remove-if-not
-       remprop rename-file rename-package replace require rest return
-       return-from revappend reverse room rotatef round rplaca rplacd
-       safety satisfies sbit scale-float schar search second sequence set
-       set-char-bit set-difference set-dispatch-macro-character
-       set-exclusive-or set-macro-character set-syntax-from-char setf setq
-       seventh sfun shadow shadowing-import shiftf short-float
-       short-float-epsilon short-float-negative-epsilon short-site-name
-       signed-byte signum simple-array simple-bit-vector
-       simple-bit-vector-p simple-string simple-string-p simple-vector
-       simple-vector-p sin single-float single-float-epsilon
-       single-float-negative-epsilon sinh sixth sleep software-type
-       software-version some sort space special special-form-p speed sqrt
-       stable-sort standard-char standard-char-p step stream
-       stream-element-type streamp string string-capitalize string-char
-       string-char-p string-downcase string-equal string-greaterp
-       string-left-trim string-lessp string-not-equal string-not-greaterp
-       string-not-lessp string-right-trim string-trim string-upcase
-       string/= string< string<= string= string> string>= stringp
-       structure sublis subseq subsetp subst subst-if subst-if-not
-       substitute substitute-if substitute-if-not subtypep svref sxhash
-       symbol symbol-function symbol-name symbol-package symbol-plist
-       symbol-value symbolp t tagbody tailp tan tanh tenth terpri the
-       third throw time trace tree-equal truename truncate type type-of
-       typecase typep unexport unintern union unless unread-char
-       unsigned-byte untrace unuse-package unwind-protect upper-case-p
-       use-package user-homedir-pathname values values-list variable
-       vector vector-pop vector-push vector-push-extend vectorp warn when
-       with-input-from-string with-open-file with-open-stream
-       with-output-to-string write write-byte write-char write-line
-       write-string write-to-string y-or-n-p yes-or-no-p zerop))))
+#+kcl (in-package :walker :use '(:lisp))
+#+kcl (in-package :iterate :use '(:lisp :walker))
+#+kcl (in-package :pcl :use '(:walker :iterate :lisp))
 
-(in-package :walker :use '(:lisp))
-(in-package :iterate :use '(:lisp :walker))
-(in-package :pcl :use '(:walker :iterate :lisp))
+(eval-when (compile load eval)
+
+(if (find-package ':walker)
+    (use-package '(:lisp) ':walker)
+    (make-package ':walker :use '(:lisp)))
+
+(if (find-package ':iterate)
+    (use-package '(:lisp :walker) ':iterate)
+    (make-package ':iterate :use '(:lisp :walker)))
+
+(if (find-package ':pcl)
+    (use-package '(:walker :iterate :lisp) ':pcl)
+    (make-package ':pcl :use '(:walker :iterate :lisp)))
 
 (export (intern (symbol-name :iterate)		;Have to do this here,
 		(find-package :iterate))	;because in the defsystem
 	(find-package :iterate))		;(later in this file)
 						;we use the symbol iterate
 						;to name the file
+)
+
+(in-package :pcl)
 
 ;;;
 ;;; Sure, its weird for this to be here, but in order to follow the rules
@@ -218,7 +86,16 @@
 ;;; 
 (defvar *the-pcl-package* (find-package :pcl))
 
-(defvar *pcl-system-date* "September 16 92 PCL (f)")
+(defvar *pcl-system-date* "September 16 92 PCL (g)")
+
+(eval-when (compile load eval)
+(defvar *pcl-proclaim*
+  '(optimize (speed 3) (safety #+kcl 0 #-kcl 1) (space 0)
+             #+lucid (compilation-speed 0)))
+)
+
+#-cmu ; see pclcom.lisp
+(proclaim *pcl-proclaim*)
 
 #+cmu
 (setf (getf ext:*herald-items* :pcl)
@@ -301,22 +178,7 @@
 (eval-when (eval compile load)
   (pushnew :excl-sun4 *features*))
 
-#+cmu
-(eval-when (compile load eval)
-  (let ((vs (lisp-implementation-version)))
-    (cond ((and (<= 2 (length vs))
-		(eql #\1 (aref vs 0))
-		(let ((d (digit-char-p (aref vs 1))))
-		  (and d (<= 6 d))))
-	   (pushnew :cmu16 *features*))
-	  ((string= "8-Dec-1992" vs)
-	   (pushnew :cmu16 *features*)
-	   (pushnew :cmu17 *features*)
-	   (when (fboundp 'pcl::original-defstruct)
-	     (setf (macro-function 'defstruct)
-		   (macro-function 'pcl::original-defstruct))))
-	  (t
-	   (error "what version of cmucl is this?")))))
+
 
 ;;; Yet Another Sort Of General System Facility and friends.
 ;;;
@@ -377,45 +239,50 @@ and load your system with:
 ;;; defsys use the value of *port* rather than #+ and #- to conditionalize
 ;;; the way they work.
 ;;; 
-(defvar *port*
-        '(#+Genera               Genera
-;         #+Genera-Release-6     Rel-6
-;         #+Genera-Release-7-1   Rel-7
-          #+Genera-Release-7-2   Rel-7
-	  #+Genera-Release-7-3   Rel-7
-          #+Genera-Release-7-1   Rel-7-1
-          #+Genera-Release-7-2   Rel-7-2
-	  #+Genera-Release-7-3   Rel-7-2	;OK for now
-	  #+Genera-Release-7-4   Rel-7-2	;OK for now
-	  #+Genera-Release-8	 Rel-8
-	  #+imach                Ivory
-	  #+Cloe-Runtime	 Cloe
-          #+Lucid                Lucid
-          #+Xerox                Xerox
-	  #+Xerox-Lyric          Xerox-Lyric
-	  #+Xerox-Medley         Xerox-Medley
-          #+TI                   TI
-          #+(and dec vax common) Vaxlisp
-	  #+gcl                  gcl 
-          #+KCL                  KCL
-          #+IBCL                 IBCL
-          #+excl                 excl
-	  #+(and excl sun4)      excl-sun4
-          #+:CMU                 CMU
-          #+HP-HPLabs            HP-HPLabs
-          #+:gclisp              gclisp
-          #+pyramid              pyramid
-          #+:coral               coral))
+(defparameter *port+dname-list*
+  (mapcar #'(lambda (x)
+	      (cons (if (consp x) (car x) x)
+		    (string-downcase (if (consp x) (cadr x) x))))
+	  '(#+Genera               (Genera symbolics)
+;           #+Genera-Release-6     (Rel-6 symbolics)
+;           #+Genera-Release-7-1   (Rel-7 symbolics)
+	    #+Genera-Release-7-2   (Rel-7 symbolics)
+	    #+Genera-Release-7-3   (Rel-7 symbolics)
+	    #+Genera-Release-7-1   (Rel-7-1 symbolics)
+	    #+Genera-Release-7-2   (Rel-7-2 symbolics)
+	    #+Genera-Release-7-3   (Rel-7-2 symbolics) ;OK for now
+	    #+Genera-Release-7-4   (Rel-7-2 symbolics) ;OK for now
+	    #+Genera-Release-8	   (Rel-8 symbolics)
+	    #+imach                (Ivory symbolics)
+	    #+Cloe-Runtime	   (Cloe symbolics)
+	    #+Lucid                Lucid
+	    #+Xerox                Xerox
+	    #+Xerox-Lyric          (Xerox-Lyric xerox)
+	    #+Xerox-Medley         (Xerox-Medley xerox)
+	    #+TI                   TI 
+	    #+(and dec vax common) Vaxlisp
+	    #+KCL                  KCL
+	    #+IBCL                 IBCL
+	    #+gcl                  gcl
+	    #+excl                 (excl franz)
+	    #+(and excl sun4)      (excl-sun4 franz)
+	    #+:CMU                 CMU
+	    #+HP-HPLabs            (HP-HPLabs hp)
+	    #+:gclisp              (gclisp gold-hill)
+	    #+pyramid              pyramid
+	    #+:coral               coral)))
+
+(defparameter *port* (mapcar #'car *port+dname-list*))
+
+(defparameter *put-impl-binaries-in-impl-directory-p*
+  nil)
 
 ;;;
 ;;; When you get a copy of PCL (by tape or by FTP), the sources files will
 ;;; have extensions of ".lisp" in particular, this file will be defsys.lisp.
 ;;; The preferred way to install pcl is to rename these files to have the
 ;;; extension which your lisp likes to use for its files.  Alternately, it
-;;; is possible not to rename the files.  If the files are not renamed to
-;;; the proper convention, the second line of the following defvar should
-;;; be changed to:
-;;;     (let ((files-renamed-p nil)
+;;; is possible not to rename the files.  See below.
 ;;;
 ;;; Note: Something people installing PCL on a machine running Unix
 ;;;       might find useful.  If you want to change the extensions
@@ -463,12 +330,20 @@ and load your system with:
 	       lucid excl :CMU HP TI :gclisp pyramid coral)
 	                                     ("lisp"  . "lbin"))))
 
+;;; Note: In previous versions of PCL, the defvar for *pathname-extensions*
+;;;       assumed that files WERE renamed, (files-renamed-p was bound to t).  
+;;;       Now, this defvar assumes that the files are not renamed, unless the
+;;;       symbol :pcl-files-renamed-p is put on the *features* list.
+
+#| ; Remove this line if you have renamed the PCL source files.
+(eval-when (compile load eval) (pushnew :pcl-files-renamed-p *features*))
+|# ; Remove this line if you have renamed the PCL source files.
+
 (defvar *pathname-extensions*
-  (let* ((files-renamed-p t)
-	 (proper-extensions *default-pathname-extensions*))
-    (cond ((null proper-extensions) '("l" . "lbin"))
-          ((null files-renamed-p) (cons "lisp" (cdr proper-extensions)))
-          (t proper-extensions))))
+  (let ((proper-extensions (or *default-pathname-extensions* 
+			       '("lisp" . "lbin"))))
+    #+pcl-files-renamed-p proper-extensions
+    #-pcl-files-renamed-p (cons "lisp" (cdr proper-extensions))))
 
 (eval-when (compile load eval)
 
@@ -497,7 +372,8 @@ and load your system with:
   name
   load-env
   comp-env
-  recomp-reasons)
+  recomp-reasons
+  port)
 
 (defun make-modules (system-description)
   (let ((modules ()))
@@ -524,7 +400,8 @@ and load your system with:
             (setq module (get-module name))
             (setf (module-load-env module) (parse-spec (cadr file))
                   (module-comp-env module) (parse-spec (caddr file))
-                  (module-recomp-reasons module) (parse-spec (cadddr file))))))
+                  (module-recomp-reasons module) (parse-spec (cadddr file))
+		  (module-port module) port))))
       (let ((filenames (mapcar #'car system-description)))
 	(sort modules #'(lambda (name1 name2)
 			  (member name2 (member name1 filenames)))
@@ -535,7 +412,8 @@ and load your system with:
   (declare (type function filter make-transform))
   (let ((transforms (list nil)))
     (dolist (m modules)
-      (when (funcall filter m transforms) (funcall make-transform m transforms)))
+      (when (funcall filter m transforms)
+	(funcall make-transform m transforms)))
     (reverse (cdr transforms))))
 
 (defun make-compile-transformation (module transforms)
@@ -543,7 +421,8 @@ and load your system with:
 	    (and (eq (car trans) ':compile)
 		 (eq (cadr trans) module)
 		 (return t)))
-    (dolist (c (module-comp-env module)) (make-load-transformation c transforms))
+    (dolist (c (module-comp-env module)) 
+      (make-load-transformation c transforms))
     (setf (cdr transforms)
 	  (remove-if #'(lambda (trans) (and (eq (car trans) :load)
 					    (eq (cadr trans) module)))
@@ -554,8 +433,10 @@ and load your system with:
 
 (defun make-load-transformation (module transforms)
   (if (assoc module *being-loaded*)
-      (throw module (setf (cdr transforms) (cdr (assoc module *being-loaded*))))
-      (let ((*being-loaded* (cons (cons module (cdr transforms)) *being-loaded*)))
+      (throw module (setf (cdr transforms)
+			  (cdr (assoc module *being-loaded*))))
+      (let ((*being-loaded* (cons (cons module (cdr transforms))
+				  *being-loaded*)))
 	(catch module
 	  (unless (dolist (trans transforms)
 		    (when (and (eq (car trans) ':load)
@@ -579,9 +460,9 @@ and load your system with:
                            (eq (cadr transform) r))
                   (return t)))
           (return t)))
-      (null (probe-file (make-binary-pathname (module-name module))))
-      (> (file-write-date (make-source-pathname (module-name module)))
-         (file-write-date (make-binary-pathname (module-name module))))))
+      (null (probe-file (make-binary-pathname module)))
+      (> (file-write-date (make-source-pathname module))
+         (file-write-date (make-binary-pathname module)))))
 
 (defun operation-transformations (name mode &optional arg)
   (let ((system (get-system name)))
@@ -653,6 +534,9 @@ and load your system with:
   (declare (ignore ignore))
   't)
 
+#+cmu17
+(defparameter *byte-files* '(defclass defcombin iterate env))
+
 (defun operate-on-system (name mode &optional arg print-only)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
@@ -664,17 +548,21 @@ and load your system with:
 	       (load-module (m)
 		 (let* ((name (module-name m))
 			(*load-verbose* nil)
-			(binary (make-binary-pathname name)))
+			(binary (make-binary-pathname m)))
 		   (load-binary name binary)))
 	       (compile-module (m)
 		 (format t "~&Compiling ~A...~%" (module-name m))
 		 (unless print-only
-		   (let  ((name (module-name m)))
-		     (compile-file (make-source-pathname name)
-				   :output-file
-				   (make-pathname :defaults
-						  (make-binary-pathname name)
-						  :version :newest))))))
+		   (compile-file (make-source-pathname m)
+				 :output-file
+				 (make-pathname :defaults
+						(make-binary-pathname m)
+						:version :newest)
+				 #+cmu17 :byte-compile #+cmu17
+				 (if (and (member (module-name m) *byte-files*)
+					  (member :small *features*))
+				     t
+				     :maybe)))))
 	(#+Genera
 	 compiler:compiler-warnings-context-bind
 	 #+TI
@@ -691,12 +579,17 @@ and load your system with:
 		     (:compile (compile-module (cadr transform)))
 		     (:load (load-module (cadr transform)))))))))))
 
-
 (defun make-source-pathname (name) (make-pathname-internal name :source))
 (defun make-binary-pathname (name) (make-pathname-internal name :binary))
 
-(defun make-pathname-internal (name type)
-  (let* ((extension (ecase type
+(defun make-pathname-internal (name-or-module type)
+  (let* ((name (if (module-p name-or-module) 
+		   (module-name name-or-module)
+		   name-or-module))
+	 (port (if (module-p name-or-module) 
+		   (module-port name-or-module)
+		   nil))
+	 (extension (ecase type
                       (:source (car *pathname-extensions*))
                       (:binary (cdr *pathname-extensions*))))
          (directory (pathname
@@ -706,10 +599,24 @@ and load your system with:
 			(cons (ecase type
 				(:source (car *system-directory*))
 				(:binary (cdr *system-directory*)))))))
+	 (dir (pathname-directory directory))
+	 (ldir (if (consp dir)
+		   dir
+		   (pathname-directory (truename directory))))
+
+	 (port-dname (when (and port 
+				(or *put-impl-binaries-in-impl-directory-p*
+				    (eq type ':source)))
+		       (cdr (assoc port *port+dname-list*))))
+	 (port-directory (if port-dname
+			     (append ldir (list "impl" port-dname))
+			     ldir))
+			     
          (pathname
            (make-pathname
              :name (string-downcase (string name))
              :type extension
+	     :directory port-directory
              :defaults directory)))
 
     #+Genera
@@ -723,18 +630,14 @@ and load your system with:
     (unless system (error "Can't find system with name ~S." name))
     (let ((*system-directory* (funcall (the function (car system))))
 	  (modules (cadr system)))
-      (mapcar #'(lambda (module)
-		  (make-source-pathname (module-name module)))
-	      modules))))
+      (mapcar #'make-source-pathname modules))))
 
 (defun system-binary-files (name)
   (let ((system (get-system name)))
     (unless system (error "Can't find system with name ~S." name))
     (let ((*system-directory* (funcall (the function (car system))))
 	  (modules (cadr system)))
-      (mapcar #'(lambda (module)
-		  (make-binary-pathname (module-name module)))
-	      modules))))
+      (mapcar #'make-binary-pathname modules))))
 
 ;;; ***                SITE SPECIFIC PCL DIRECTORY                        ***
 ;;;
@@ -757,7 +660,9 @@ and load your system with:
 ;;; ***                                                                   ***
 
 (defun load-truename (&optional (errorp nil))
-  (flet ((bad-time ()
+  #+cmu (declare (ignore errorp))
+  (flet (#+(or Lispm Xerox LUCID)
+	 (bad-time ()
 	   (when errorp
 	     (error "LOAD-TRUENAME called but a file isn't being loaded."))))
     #+Lispm  (or sys:fdefine-file-pathname (bad-time))
@@ -774,15 +679,15 @@ and load your system with:
     #+cmu17 *load-truename*
     #-(or Lispm excl Xerox (and dec vax common) LUCID akcl cmu17) nil))
 
-#-(or (and cmu (not cmu17)) Symbolics)
+#-(or cmu Symbolics)
 (defvar *pcl-directory*
 	(or (load-truename t)
 	    (error "Because load-truename is not implemented in this port~%~
                     of PCL, you must manually edit the definition of the~%~
                     variable *pcl-directory* in the file defsys.lisp.")))
 
-#+(and cmu (not cmu17))
-(defvar *pcl-directory* (pathname "pcl:"))
+#+cmu 
+(defvar *pcl-directory* (pathname "target:pcl/"))
 
 #+Genera
 (defvar *pcl-directory*
@@ -820,7 +725,7 @@ and load your system with:
    (xerox-patches   t            t            ()                xerox)
    (kcl-patches     t            t            ()                kcl)
    (ibcl-patches    t            t            ()                ibcl)
-   (gcl-patches     t            t            ()                gclisp)
+   (gold-patches    t            t            ()                gclisp)
    
    (pkg             t            t            ())
    (sys-proclaim    t            t            ()                kcl)
@@ -836,9 +741,9 @@ and load your system with:
    (Xerox-low      (low)         (low)        (low)            Xerox)
    (ti-low         (low)         (low)        (low)            TI)
    (vaxl-low       (low)         (low)        (low)            vaxlisp)
-   (gcl-low       (low)         (low)        (low)            gcl)
    (kcl-low        (low)         (low)        (low)            KCL)
    (ibcl-low       (low)         (low)        (low)            IBCL)
+   (gcl-low        (low)         (low)        (low)            gcl)
    (excl-low       (low)         (low)        (low)            excl)
    (cmu-low        (low)         (low)        (low)            CMU)
    (hp-low         (low)         (low)        (low)            HP-HPLabs)
@@ -851,13 +756,6 @@ and load your system with:
    (defs        t                                   t (defclass macros iterate))
    (fngen       t                                   t (low))
    (cache       t                                   t (low defs))
-   ;;(lap         t                                   t (low)    excl-sun4)
-   ;;(plap        t                                   t (low)    excl-sun4)
-   ;;(cpatch      t                                   t (low)    excl-sun4)
-   ;;(quadlap     t                                   t (low)    excl-sun4)
-   ;;(dlap        t                                   t (defs low fin cache lap) 
-   ;;	                                                         excl-sun4)
-   ;;#-excl-sun4
    (dlisp       t                                   t (defs low fin cache))
    (dlisp2      t                                   t (low fin cache dlisp))
    (boot        t                                   t (defs fin))
@@ -877,8 +775,6 @@ and load your system with:
    (fixup       t                                   t (boot defs low fin))
    (defcombin   t                                   t (defclass boot defs low fin))
    (ctypes      t                                   t (defclass defcombin))
-   #+ignore
-   (construct   t                                   t (defclass boot defs low))
    (env         t                                   t (defclass boot defs low fin))
    (compat      t                                   t ())
    (precom1     (dlisp)                             t (defs low cache fin dfun))
@@ -1050,8 +946,6 @@ and load your system with:
 		(or (c::info setf inverse sym)
 		    (c::info setf expander sym)
 		    (c::info type kind sym)
-		    (c::info type structure-info sym)
-		    (c::info type defined-structure-info sym)
 		    (c::info function macro-function sym)
 		    (c::info function compiler-macro-function sym)))
 	    (unintern sym pkg)
